@@ -319,7 +319,7 @@ c----        include '../Zevhnv.h'
         integer ntpc
 c           <>pt for NN~,          DD~
         real*8 ptnnb/500.d-3/, ptddb/750.d-3/, ptavpi/330.d-3/,
-     *         ptavk/479.d-3/
+     *         ptavk/479.d-3/, ptaveta/480.d-3/
 c
         ntpc = 0
 c                 (n,n~)
@@ -335,6 +335,9 @@ c                 pi+/-
         call cspt(pttmp, Npic,  a, ntpc)
 c                 pi0
         call cspt(pttmp, Npi0,  a, ntpc)
+c                eta
+        pttmp = ptaveta*Ptnorm/ptavpi
+        call cspt(pttmp, Neta, a, ntpc)
 c                 kaon +/ -
         pttmp = ptavk*Ptnorm/ptavpi
         call cspt(pttmp, Nkch, a, ntpc)
