@@ -7,6 +7,7 @@ c  *
       subroutine chookBgRun
       implicit none
 #include "Zmanagerp.h"
+
 c          ///////////
       common /testcos/sumg, ng, nth, nev
       real*8 sumg
@@ -60,6 +61,7 @@ c     //////////////
 c      write(*, *) ' bigin event generation'
       call cqIniRn(seed)
 c      write(*,*) ' seed=', seed
+      call cwriteSeed
       sumg = 0.
       ng = 0
       nev = nev + 1
@@ -89,13 +91,15 @@ c          ///////////
       common /testcos/sumg, ng, nth, nev
       real*8 sumg
       integer ng, nth, nev
-c     //////////////
+c//////////////
+
 
 c
 c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
-      if(id .eq. 2) then
+c      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
+      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
 c            output typical quantities.
         write(*, *) 
      *  aTrack.where,   !  observation level. integer*2.  1 is highest.
@@ -181,8 +185,8 @@ c         write(*, *) (ASObsSites(i).age,   i=1, NoOfASSites)
      *           sngl(ASObsSites(i).age), sngl(fdepth),
      *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)  
          enddo
-         write(*, *)
       endif
+      write(*, *)
       end
 
 
